@@ -54,8 +54,8 @@ class Status:
                             "enabled": self.father.framework.machine.info["spindle"][0]["enabled"],
                             "direction": self.father.framework.machine.info["spindle"][0]["direction"],
                             "speed": self.father.framework.machine.info["spindle"][0]["speed"],
-                            "min_override": inifile.find("DISPLAY", "MIN_SPINDLE_OVERRIDE"),
-                            "max_override": inifile.find("DISPLAY", "MAX_SPINDLE_OVERRIDE"),
+                            "min_override": float(inifile.find("DISPLAY", "MIN_SPINDLE_OVERRIDE")),
+                            "max_override": float(inifile.find("DISPLAY", "MAX_SPINDLE_OVERRIDE")),
                             "override": self.father.framework.machine.info["spindle"][0]["override"],
                             "override_enabled": self.father.framework.machine.info["spindle"][0]["override_enabled"]
                         },
